<?php 

class Lernzirkel_Install extends Lernzirkel {
    /**
     * Add interval to deactivate blocked users
     *
     * @param array $schedules
     * @return array $schedules
     */
    function nsrc_cron_add_interval($schedules) {
        // Adds once weekly to the existing schedules.
        $schedules['unblock_users'] = array(
            'interval' => 2 * 60,
            'display' => __( 'Alle 2 Minuten' )
        );
        return $schedules;
    }
    
    /**
     * Create tables on activation
     */
    function activate_lernzirkel() {
        
        global $wpdb;
        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        
        $charset_collate = $wpdb->get_charset_collate();
        
        $sql = "
        CREATE TABLE IF NOT EXISTS ".$wpdb->prefix.LERNZIRKEL_NAME." (
            id int(11) NOT NULL AUTO_INCREMENT,
            name varchar(255) NOT NULL,
            created_at timestamp DEFAULT NOW(),
            created_by INT NOT NULL,
            lastchanged DATETIME ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY(id),
            UNIQUE KEY(name)
        ) $charset_collate;
        ";
        dbDelta( $sql );
        
        $error = $wpdb->print_error();
        if( $error !== false ) {
            die("Couldn't create table ".$wpdb->prefix.LERNZIRKEL_NAME.": <br/>$sql<br/>See error:<br/><br/>$error");
        }
        
        $sql = "
        CREATE TABLE  IF NOT EXISTS ".$wpdb->prefix.LERNZIRKEL_CHAT_NAME." (
            id int(11) NOT NULL AUTO_INCREMENT,
            user_id_from bigint NOT NULL REFERENCES ".$wpdb->users."(ID),
            user_id_to bigint NOT NULL REFERENCES ".$wpdb->users."(ID),
            post_id bigint NOT NULL REFERENCES ".$wpdb->posts."(ID),
            lernerli_id bigint NULL REFERENCES ".$wpdb->postmeta."(meta_id),
            message TEXT NOT NULL,
            created_at timestamp DEFAULT NOW(),
            PRIMARY KEY(id)
        ) $charset_collate;
        ";
        dbDelta( $sql );
        
        $error = $wpdb->print_error();
        if( $error !== false ) {
            die("Couldn't create table ".$wpdb->prefix.LERNZIRKEL_CHAT_NAME.": <br/>$sql<br/>See error:<br/><br/>$error");
        }
        
        $sql = "
        CREATE TABLE  IF NOT EXISTS ".$wpdb->prefix.LERNZIRKEL_2USER." (
            lernzirkel_id bigint NOT NULL REFERENCES ".$wpdb->prefix.LERNZIRKEL_NAME."(id),
            user_id bigint NOT NULL REFERENCES ".$wpdb->users."(ID),
            created_at timestamp DEFAULT NOW(),
            created_by INT NOT NULL,
            PRIMARY KEY(lernzirkel_id, user_id)
        ) $charset_collate;
        ";
        dbDelta( $sql );
        
        $error = $wpdb->print_error();
        if( $error !== false ) {
            die("Couldn't create table ".$wpdb->prefix.LERNZIRKEL_CHAT_NAME.": <br/>$sql<br/>See error:<br/><br/>$error");
        }
        
    }
    
    /**
     * Rolle "Lernzirkel" ergänzen, hat keine weiteren Rechte
     */
    function add_role_lernzirkel() {
        add_role(
            'lernzirkel',
            'Lernzirkel',
            array()
            );
        add_role(
            'lernzirkel_admin',
            'Lernzirkel-Administrator',
            array()
            );
    }
    
}

?>