<?php
/*
 Plugin Name: NSRC Lernzirkel
 Plugin URI: http://www.haw-hamburg.de
 Description: Chat für Lernzirkel, kann mit dem NSRC-Lernkorb zusammen genutzt werden
 Version: 1.1.0 (22.05.2021)
 Author: Hamburg Open Online University (HOOU) / Anne Peters (Konzept) / Netsource Data Systems (Programmierung) / Aram und Sanem (Grafiken)
 
 Requires at least: 5.5.3
 License:           MIT
 License URI:       https://opensource.org/licenses/mit-license.php
 
*/

require_once 'NSRC-lernzirkel-install.php';
require_once 'NSRC-lernzirkel-frontend.php';
require_once 'NSRC-lernzirkel-userregistration.php';
require_once 'NSRC-lernzirkel-admin.php';


add_action(     'init',                         array('Lernzirkel_Install', 'add_role_lernzirkel') );
add_filter(     'cron_schedules',               array('Lernzirkel_Install', 'nsrc_cron_add_interval') );
register_activation_hook( __FILE__,             array('Lernzirkel_Install','activate_lernzirkel') );

add_action(     'wp_head',                      array('Lernzirkel_Frontend','nsrc_add_stylesheet_head') );
add_action(     'parse_query',                  array('Lernzirkel_Frontend', 'nsrc_add_chat_2_user') );
add_action(     'parse_query',                  array('Lernzirkel_Frontend', 'nsrc_add_lernzirkel') );
add_filter(     'query_vars',                   array('Lernzirkel_Frontend', 'nsrc_add_query_vars' ) );
add_shortcode(  'lernzirkel_chat',              array('Lernzirkel_Frontend','nsrc_lernzirkel_chat_shortcode') );
add_shortcode(  'lernzirkel',                   array('Lernzirkel_Frontend','nsrc_lernzirkel_chat_shortcode') );
add_action(     'authenticate',                 array('Lernzirkel_Frontend','nsrc_lernzirkel_block_user_from_login_error'), 200, 3 );
add_action(     'lernzirkel_chat_loeschen',     array('Lernzirkel_Frontend','lernzirkel_chat_loeschen'));
add_action(     'lernzirkel_delete_old_user',     array('Lernzirkel_Frontend','lernzirkel_delete_old_user'));
add_action(     'lernzirkel_reactivate_user_afterMinutes',     array('Lernzirkel_Frontend','lernzirkel_reactivate_user_afterMinutes'));

add_action(     'login_init',                   array('Lernzirkel_UserRegistration','login_init') );
add_action(     'register_form',                array('Lernzirkel_UserRegistration','registration_form') );
add_action(     'login_form_register',          array('Lernzirkel_UserRegistration','registration_setUsername') );
add_filter(     'user_row_actions',             array('Lernzirkel_UserRegistration','nsrc_useraction_unlockuserlink'), 10, 2 );
add_action(     'admin_init',                   array('Lernzirkel_UserRegistration','nsrc_useraction_unlockuser'));
add_action(     'user_profile_update_errors',   array('Lernzirkel_UserRegistration','user_profile_update_errors'), 10, 3 );
add_action(     'registration_errors',          array('Lernzirkel_UserRegistration','user_profile_update_errors'), 10, 3 );
add_action(     'register_new_user'         ,   array('Lernzirkel_UserRegistration','register_new_user') );
add_action(     'login_head',                   array('Lernzirkel_UserRegistration','login_head') );
add_action(     'login_form_fertig',            array('Lernzirkel_UserRegistration','login_form_fertig') );


add_filter(     'plugin_action_links_' . plugin_basename(__FILE__), array('Lernzirkel_Admin','nsrc_add_pluginlinks') );
add_action(     'admin_menu',                   array('Lernzirkel_Admin','nsrc_add_adminmenu_description_lernkorb') );
add_filter(     'manage_users_columns',         array('Lernzirkel_Admin','manage_users_columns') );
add_action(     'manage_users_custom_column',   array('Lernzirkel_Admin','manage_users_custom_column'), 10, 3 );
add_filter(     'bulk_actions-users',       array('Lernzirkel_Admin','register_my_bulk_actions') );
add_filter(     'handle_bulk_actions-users', array('Lernzirkel_Admin','my_bulk_action_handler'), 10, 3 );
add_action(     'admin_print_footer_scripts',   array('Lernzirkel_Admin','nsrc_lernzirkel_quicktag') );



if ( ! wp_next_scheduled( 'lernzirkel_chat_loeschen' ) ) {
    wp_schedule_event( time(), 'daily', 'lernzirkel_chat_loeschen' );
}
if ( ! wp_next_scheduled( 'lernzirkel_delete_old_user' ) ) {
    wp_schedule_event( time(), 'daily', 'lernzirkel_delete_old_user' );
}
if ( ! wp_next_scheduled( 'lernzirkel_reactivate_user_afterMinutes' ) ) {
    wp_schedule_event( time(), 'unblock_users', 'lernzirkel_reactivate_user_afterMinutes' );
}


define('LERNZIRKEL_NAME',"lernzirkel");
define('LERNZIRKEL_CHAT_NAME', LERNZIRKEL_NAME."_chat");
define('LERNZIRKEL_2USER', LERNZIRKEL_NAME."_2_user");
define('LERNZIRKEL_METAKEY_BLOCK_COUNT', LERNZIRKEL_NAME.'_blockcount');
define('LERNZIRKEL_METAKEY_BLOCK_DATE', LERNZIRKEL_NAME.'_blockdate');
define('LERNZIRKEL_METAKEY_BLOCK_IP', LERNZIRKEL_NAME.'_blockedip');
define('LERNZIRKEL_METAKEY_BLOCK_COUNT_GENERAL', LERNZIRKEL_NAME.'_blocked_general');


class Lernzirkel {
    
    function get_redirect() {
        return get_home_url();
    }
    
    function login2Tier($username) {
        $tiere = json_decode( Lernzirkel_Admin::get_option_value('netsource_lernzirkel_option_tiere') );
        foreach($tiere as $i => $t ) {
            if( preg_match("/^".$t[1]."\d+$/", $username) ) return $i;
        }
        return 0;
    }
    
}

?>